@@ -35,6 +35,7 @@ from instagrapi.mixins.timeline import ReelsMixin
 from instagrapi.mixins.totp import TOTPMixin
 from instagrapi.mixins.user import UserMixin
 from instagrapi.mixins.video import DownloadVideoMixin, UploadVideoMixin
+from instagrapi.mixins.multiple_accounts import MultipleAccountsMixin
 
 requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
 
@@ -74,13 +75,15 @@ class Client(
     ReelsMixin,
     BloksMixin,
     TOTPMixin,
+    MultipleAccountsMixin
 ):
     proxy = None
     logger = logging.getLogger("instagrapi")
 
-    def __init__(self, settings: dict = {}, proxy: str = None, **kwargs):
+    def __init__(self, settings: dict = {}, proxy: str = None, delay_range: list = None, **kwargs):
         super().__init__(**kwargs)
         self.settings = settings
+        self.delay_range = delay_range
         self.set_proxy(proxy)
         self.init()
 
