@@ -307,9 +307,10 @@ class UserMixin:
         -------
         dict
         """
+        user_ids_str = ','.join(user_ids)
         result = self.private_request(
             "friendships/show_many/",
-            data={"user_ids": user_ids},
+            data={"user_ids": user_ids_str, '_uuid': self.uuid},
             with_signature=False
         )
         return result["friendship_statuses"]
